//========================================================================================
//
//	File:				HelloCmd.h
//	Release Version:	$ 1.0d11 $
//
//	Author:				M.Boetcher
//
//	Copyright:	 1995 by Apple Computer, Inc., all rights reserved.
//
//========================================================================================

#ifndef HELLOCMD_H
#define HELLOCMD_H

// ----- Framework Includes -----

#ifndef FWEDCMD_H
#include "FWEdCmd.h"
#endif

#ifndef FWDRCMD_H
#include "FWDrCmd.h"
#endif

#ifndef FWBNDSTR_H
#include "FWBndStr.h"
#endif

//========================================================================================
// Forward Declarations
//========================================================================================

class FW_CLASS_ATTR CHelloPart;
class FW_CLASS_ATTR CHelloSelection;

//========================================================================================
// CHelloEditCommand
//========================================================================================

class FW_CLASS_ATTR CHelloEditCommand : public FW_CEditCommand
{
//--------------------------------
//	Initialization/Destruction
//
  public:
	CHelloEditCommand(Environment* ev,
					  ODCommandID id,
					  CHelloPart* itsPart,
					  FW_CFrame* frame);

	virtual ~CHelloEditCommand();

//--------------------------------
//	Inherited API
//
	virtual void		UndoIt(Environment *ev);	// Override
	virtual void		RedoIt(Environment *ev);	// Override
	virtual void		SaveUndoState(Environment *ev);	// Override

//--------------------------------
//	New API
//
  private:
	void RemoveSelection(Environment* ev);
	void RestoreSelection(Environment* ev);
	void SwapSelection(Environment* ev);

//--------------------------------
//	Data Members
//
  private:
	CHelloPart*			fHelloPart;

	// Saved data for undo/redo
	FW_CString255		fSavedTextData;		// saved string
	FW_Boolean			fSavedSetting;		// saved Hello part setting
};

//========================================================================================
//	class CHelloDragCommand
//========================================================================================

class FW_CLASS_ATTR CHelloDragCommand : public FW_CDragCommand
{
  public:
	CHelloDragCommand(Environment* ev,
					  CHelloPart* part,
					  FW_CFrame* frame);
	virtual ~CHelloDragCommand();

//--------------------------------
//	Inherited API
//
	virtual void		UndoIt(Environment *ev);	// Override
	virtual void		RedoIt(Environment *ev);	// Override
	virtual void		SaveUndoState(Environment *ev);	// Override

//--------------------------------
//	Data Members
//
  private:
	CHelloPart*			fHelloPart;

	// Saved data for undo/redo
	FW_CString255		fSavedTextData;		// saved string
	FW_Boolean			fSavedSetting;		// saved Hello part setting
};

//========================================================================================
//	class CHelloDropCommand
//========================================================================================

class FW_CLASS_ATTR CHelloDropCommand : public FW_CDropCommand
{
  public:
	CHelloDropCommand(Environment *ev,
					  CHelloPart* itsPart,
					  FW_CFrame* frame,
					  ODDragItemIterator* dropInfo, 
					  ODFacet* odFacet,
					  const FW_CPoint& dropPoint);

	virtual ~CHelloDropCommand();

//--------------------------------
//	Inherited API
//
	virtual void		UndoIt(Environment *ev);	// Override
	virtual void		RedoIt(Environment *ev);	// Override
	virtual void		SaveUndoState(Environment *ev);	// Override

//--------------------------------
//	New API
//
  private:
	void SwapSelection(Environment* ev);

//--------------------------------
//	Data Members
//
  private:
	CHelloPart*			fHelloPart;

	// Saved data for undo/redo
	FW_CString255		fSavedTextData;		// saved string
	FW_Boolean			fSavedSetting;		// saved Hello part setting
};


#endif
